powered by
Displays the HDX color palettes. By default, shows all values for all palettes. You can change the number of values for each palette or only show a subset of the available palettes (from hdx_pal_...()).
hdx_pal_...()
hdx_display_pal( n = NULL, palette = c("discrete", "primary", "brand", "error", "gray", "mint", "sapphire", "tomato") )
Plot of HDX color palettes.
Number of colors for each palette to show.
Character vector of palettes to show.
hdx_display_pal() hdx_display_pal(n = 3)
Run the code above in your browser using DataLab